select

Function select 

pub fn select() -> Result<Option<Branch>>
Prompts the user to select a branch from all available branches.

The previously checked-out branch (@{-1}) is placed first when available. Then up to seven branches whose latest commit was made with the configured user.email are shown before the remaining recency-ordered list.

Errors

  • If repository discovery fails.
  • If [ytil_git::branch::get_all_no_redundant] fails.
  • If crate::minimal_select fails.